@@ -1,7 +1,7 @@
 -- -
 -- #%L
 -- %%
--- Copyright (C) 2005 - 2025 Kuali, Inc. - All Rights Reserved
+-- Copyright (C) 2005 - 2026 Kuali, Inc. - All Rights Reserved
 -- %%
 -- You may use and modify this code under the terms of the Kuali, Inc.
 -- Pre-Release License Agreement. You may not distribute it.
@@ -13,8 +13,6 @@
 
 DELIMITER /
 
-
--- KULRICE-7237: KRNS_NTE_T is selected by a field with no indexes - full table scan every time
-create index KRNS_NTE_TI1 on KRNS_NTE_T (RMT_OBJ_ID)
+ALTER TABLE KRSB_MSG_QUE_T CHANGE SVC_NMSPC APPL_ID VARCHAR(255)
 /
 DELIMITER ;
